@@ -1,8 +1,8 @@
 import os
 import tempfile
+import traceback
 from pathlib import Path
 from urllib.parse import urlparse
-import traceback
 
 import ldm.modules.attention
 import ldm.modules.diffusionmodules.model
@@ -114,13 +114,17 @@ def unload_model(context: Context, **kwargs):
 
 def load_diffusers_model(context: Context, model_path, config_file_path):
     import torch
-    from .convert_from_ckpt import download_from_original_stable_diffusion_ckpt
     from diffusers import (
         StableDiffusionImg2ImgPipeline,
-        StableDiffusionInpaintPipelineLegacy,
         StableDiffusionInpaintPipeline,
+        StableDiffusionInpaintPipelineLegacy,
     )
+    from compel import Compel
+
     from sdkit.generate.sampler import diffusers_samplers
+    from sdkit.utils import gc
+
+    from .convert_from_ckpt import download_from_original_stable_diffusion_ckpt
 
     log.info("loading on diffusers")
 
@@ -141,15 +145,41 @@ def load_diffusers_model(context: Context, model_path, config_file_path):
         from_safetensors=model_path.endswith(".safetensors"),
         upcast_attention=(attn_precision == "fp32"),
         is_img2img=False,
+        device="cpu",
     )
 
     default_pipe.requires_safety_checker = False
     default_pipe.safety_checker = None
 
-    default_pipe = default_pipe.to(context.device)
-    if context.half_precision:
-        default_pipe = default_pipe.to(torch.float16)
-    default_pipe.enable_attention_slicing()
+    save_tensor_file(default_pipe.vae.state_dict(), os.path.join(tempfile.gettempdir(), "sd-base-vae.safetensors"))
+
+    if context.vram_usage_level == "low" and context.device != "mps":
+        default_pipe.enable_sequential_cpu_offload()
+    else:
+        if context.half_precision:
+            default_pipe = default_pipe.to(context.device, torch.float16)
+        else:
+            default_pipe = default_pipe.to(context.device)
+
+    if context.vram_usage_level != "high":
+        default_pipe.enable_attention_slicing()
+
+    try:
+        import xformers
+
+        default_pipe.enable_xformers_memory_efficient_attention()
+    except:
+        pass
+
+    if torch.__version__.startswith("2."):
+        default_pipe.enable_vae_slicing()
+
+    # make the compel prompt parser object
+    compel = Compel(
+        tokenizer=default_pipe.tokenizer,
+        text_encoder=default_pipe.text_encoder,
+        truncate_long_prompts=False,
+    )
 
     # make samplers
     diffusers_samplers.make_samplers(default_pipe.scheduler)
@@ -160,6 +190,7 @@ def load_diffusers_model(context: Context, model_path, config_file_path):
             "config": config,
             "default": default_pipe,
             "inpainting": default_pipe,
+            "compel": compel,
         }
 
     pipe_txt2img = default_pipe
@@ -189,7 +220,7 @@ def load_diffusers_model(context: Context, model_path, config_file_path):
         requires_safety_checker=False,
     )
 
-    save_tensor_file(default_pipe.vae.state_dict(), os.path.join(tempfile.gettempdir(), "sd-base-vae.safetensors"))
+    gc(context)
 
     log.info("Loaded on diffusers")
 
@@ -199,6 +230,7 @@ def load_diffusers_model(context: Context, model_path, config_file_path):
         "txt2img": pipe_txt2img,
         "img2img": pipe_img2img,
         "inpainting": pipe_inpainting,
+        "compel": compel,
     }
 
 
@@ -209,9 +241,12 @@ def test_and_fix_precision(context, model, config, attn_precision):
     # test precision
     try:
         from sdkit.generate import generate_images
+
         from . import optimizations
 
-        images = generate_images(context, prompt="Horse", width=64, height=64, num_inference_steps=1)
+        images = generate_images(
+            context, prompt="Horse", width=64, height=64, num_inference_steps=1, sampler_name="plms"
+        )
         is_black_image = not images[0].getbbox()
         if is_black_image and attn_precision == "fp16":
             attn_precision = "fp32"
@@ -223,7 +258,7 @@ def test_and_fix_precision(context, model, config, attn_precision):
             is_black_image = not images[0].getbbox()
 
         if is_black_image and attn_precision == "fp32" and context.half_precision:
-            log.info(f"trying full precision")
+            log.info("trying full precision")
             context.orig_half_precision = context.half_precision
             context.half_precision = False
             config.model.params.unet_config.params.use_fp16 = False
